==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXConsole.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXConsole;no warnings;($consoleInitFD=(-(0x0027+ 7793-0x1e97)));($buffer
=(""));($console=(-(0x0dc6+ 1902-0x1533)));($consoleChildOUT=(-
(0x1043+ 3293-0x1d1f)));($consoleChildIN=(-(0x0a39+ 3112-0x1660)));sub 
__initConsole{if (consoleRuning ()){Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$consoleInitFD));return;}($buffer=("\x20" x (0x2148+ 457-0x2211)));my (
$consoleDescriptorError);(my $consoleInitFD=createConsoleDescriptor ((
\$consoleDescriptorError),(\$buffer),(0x1ea8+ 401-0x1f39)));(
$NXConsole::consoleInitFD=$consoleInitFD);if (($NXConsole::consoleInitFD==(-
(0x1bf7+ 1693-0x2293)))){if (((not (defined ($consoleDescriptorError)))or (
$consoleDescriptorError eq ("")))){main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x57\x69\x74\x68\x6f\x75\x74\x52\x65\x61\x73\x6f\x6e"
);}else{main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65"
,$consoleDescriptorError);}}else{Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x73\x74\x61\x72\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$NXConsole::consoleInitFD));}}sub closeConsole{if (consoleRuning ()){
Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x63\x6c\x6f\x73\x69\x6e\x67\x20\x46\x44\x23"
.$consoleInitFD));main::nxclose ($consoleInitFD);($consoleInitFD=(-
(0x1749+ 1812-0x1e5c)));}}sub __setupConsole{($consolePath=libnxh::NXGetConsole 
($consoleInitFD,(\$buffer),(0x1b19+ 2621-0x2456)));if (($consolePath==(-
(0x157b+ 2219-0x1e25)))){(my $errorString=Common::NXCore::reportErrorFromNXPL ((
(
"\x43\x6f\x75\x6c\x64\x20\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20"
.$consoleInitFD)."\x2e")));main::node_finish_error_simple (
"\x65\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x50\x61\x74\x68"
,$errorString);}else{Logger::debug (((
"\x4e\x58\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$consolePath)."\x2e"));}}sub __createChildInOut{($consoleChildIN=main::nxopen (
$consolePath,$NXBits::O_RDWR,(0x0faa+ 5918-0x26c8)));if (($consoleChildIN==(-
(0x0c39+ 4191-0x1c97)))){main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}(
$consoleChildOUT=main::nxopen ($consolePath,$NXBits::O_RDWR,
(0x1b9b+ 1630-0x21f9)));if (($consoleChildOUT==(-(0x005d+ 5477-0x15c1)))){
main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}}
sub __setControllingChildFD{(my $setConsole=libnxh::NXConsoleSetControlling (
getConsoleChildOUT ()));if (($setConsole==(-(0x01d9+ 7400-0x1ec0)))){
Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x53\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x28"
.getConsoleDescriptor ())."\x29\x20\x66\x61\x69\x6c\x65\x64\x2e"));}
Logger::debug (((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x3a\x3a\x5f\x5f\x73\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x43\x68\x69\x6c\x64\x46\x44\x28"
.getConsoleDescriptor ()).("\x29\x20\x72\x65\x74\x75\x72\x6e\x20".$setConsole)))
;}sub __setInheritableChildFD{Common::NXCore::nxDescriptorInheritable (
getConsoleChildIN (),(0x0914+ 3633-0x1745));
Common::NXCore::nxDescriptorInheritable (getConsoleChildOUT (),
(0x0229+ 1747-0x08fc));}sub createConsole{__initConsole ();__setupConsole ();
__createChildInOut ();__setControllingChildFD ();__setInheritableChildFD ();}sub
 getConsoleDescriptor{return ($consoleInitFD);}sub getConsoleChildIN{return (
$consoleChildIN);}sub getConsoleChildOUT{return ($consoleChildOUT);}sub 
createConsoleDescriptor{(my $ref_errorMessag=shift (@_));(my $buffer=shift (@_))
;(my $size=shift (@_));(my ($package,$filename,$line,$sub)=caller (
(0x049f+ 5127-0x18a5)));if (($sub eq (""))){($sub=$package);}if ((not ((defined 
($buffer)||(!defined ($size)))))){Logger::error (((((((
"\x63\x72\x65\x61\x74\x65\x43\x6f\x6e\x73\x6f\x6c\x65\x44\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x3a\x20\x69\x6e\x76\x61\x6c\x69\x64\x20\x63\x61\x6c\x6c\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e\x20\x42\x75\x66\x66\x65\x72\x20\x3d\x20").$buffer).
"\x2c\x20\x73\x69\x7a\x65\x20\x3d\x20").$size)."\x2e"));nxexit ();}Logger::debug
 (((
"\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));(my $ret=libnxh::NXConsole ($buffer,$size));(my $error=
libnxh::NXGetErrorName ());($$ref_errorMessag=libnxh::NXGetErrorString ());if ((
$ret==(-(0x0143+ 8333-0x21cf)))){Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x63\x72\x65\x61\x74\x65\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));return ($ret);}Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x3a\x20\x46\x44\x23"
.$ret)."\x2e"));Common::NXCore::nxDescriptorInheritable ($ret,
(0x0b1f+ 6977-0x2660));Common::NXCore::closeSocketAtFinish ($ret);return ($ret);
}sub consoleRuning{if (($consoleInitFD==(-(0x1606+ 4165-0x264a)))){return (
(0x12ab+ 4225-0x232c));}return ((0x06e5+ 3990-0x167a));}"\x3f\x3f\x3f";

==> nomachine-8.7.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXConsole.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXConsole;no warnings;($consoleInitFD=(-(0x0613+ 5666-0x1c34)));($buffer
=(""));($console=(-(0x0375+ 6186-0x1b9e)));($consoleChildOUT=(-
(0x0562+ 8487-0x2688)));($consoleChildIN=(-(0x070d+ 990-0x0aea)));sub 
__initConsole{if (consoleRuning ()){Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$consoleInitFD));return;}($buffer=("\x20" x (0x0183+ 5825-0x1744)));my (
$consoleDescriptorError);(my $consoleInitFD=createConsoleDescriptor ((
\$consoleDescriptorError),(\$buffer),(0x0196+ 6861-0x1b63)));(
$NXConsole::consoleInitFD=$consoleInitFD);if (($NXConsole::consoleInitFD==(-
(0x0f62+ 2193-0x17f2)))){if (((not (defined ($consoleDescriptorError)))or (
$consoleDescriptorError eq ("")))){main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x57\x69\x74\x68\x6f\x75\x74\x52\x65\x61\x73\x6f\x6e"
);}else{main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65"
,$consoleDescriptorError);}}else{Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x73\x74\x61\x72\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$NXConsole::consoleInitFD));}}sub closeConsole{if (consoleRuning ()){
Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x63\x6c\x6f\x73\x69\x6e\x67\x20\x46\x44\x23"
.$consoleInitFD));main::nxclose ($consoleInitFD);($consoleInitFD=(-
(0x0604+ 3157-0x1258)));}}sub __setupConsole{($consolePath=libnxh::NXGetConsole 
($consoleInitFD,(\$buffer),(0x22d7+ 340-0x232b)));if (($consolePath==(-
(0x12e4+ 2761-0x1dac)))){(my $errorString=Common::NXCore::reportErrorFromNXPL ((
(
"\x43\x6f\x75\x6c\x64\x20\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20"
.$consoleInitFD)."\x2e")));main::node_finish_error_simple (
"\x65\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x50\x61\x74\x68"
,$errorString);}else{Logger::debug (((
"\x4e\x58\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$consolePath)."\x2e"));}}sub __createChildInOut{($consoleChildIN=main::nxopen (
$consolePath,$NXBits::O_RDWR,(0x12df+ 1142-0x1755)));if (($consoleChildIN==(-
(0x1239+ 613-0x149d)))){main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}(
$consoleChildOUT=main::nxopen ($consolePath,$NXBits::O_RDWR,
(0x1597+ 3192-0x220f)));if (($consoleChildOUT==(-(0x0f95+ 3424-0x1cf4)))){
main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}}
sub __setControllingChildFD{(my $setConsole=libnxh::NXConsoleSetControlling (
getConsoleChildOUT ()));if (($setConsole==(-(0x0da5+ 3595-0x1baf)))){
Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x53\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x28"
.getConsoleDescriptor ())."\x29\x20\x66\x61\x69\x6c\x65\x64\x2e"));}
Logger::debug (((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x3a\x3a\x5f\x5f\x73\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x43\x68\x69\x6c\x64\x46\x44\x28"
.getConsoleDescriptor ()).("\x29\x20\x72\x65\x74\x75\x72\x6e\x20".$setConsole)))
;}sub __setInheritableChildFD{Common::NXCore::nxDescriptorInheritable (
getConsoleChildIN (),(0x0345+ 1963-0x0af0));
Common::NXCore::nxDescriptorInheritable (getConsoleChildOUT (),
(0x05dc+ 1933-0x0d69));}sub createConsole{__initConsole ();__setupConsole ();
__createChildInOut ();__setControllingChildFD ();__setInheritableChildFD ();}sub
 getConsoleDescriptor{return ($consoleInitFD);}sub getConsoleChildIN{return (
$consoleChildIN);}sub getConsoleChildOUT{return ($consoleChildOUT);}sub 
createConsoleDescriptor{(my $ref_errorMessag=shift (@_));(my $buffer=shift (@_))
;(my $size=shift (@_));(my ($package,$filename,$line,$sub)=caller (
(0x0d59+ 1115-0x11b3)));if (($sub eq (""))){($sub=$package);}if ((not ((defined 
($buffer)||(!defined ($size)))))){Logger::error (((((((
"\x63\x72\x65\x61\x74\x65\x43\x6f\x6e\x73\x6f\x6c\x65\x44\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x3a\x20\x69\x6e\x76\x61\x6c\x69\x64\x20\x63\x61\x6c\x6c\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e\x20\x42\x75\x66\x66\x65\x72\x20\x3d\x20").$buffer).
"\x2c\x20\x73\x69\x7a\x65\x20\x3d\x20").$size)."\x2e"));nxexit ();}Logger::debug
 (((
"\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));(my $ret=libnxh::NXConsole ($buffer,$size));(my $error=
libnxh::NXGetErrorName ());($$ref_errorMessag=libnxh::NXGetErrorString ());if ((
$ret==(-(0x2116+ 1505-0x26f6)))){Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x63\x72\x65\x61\x74\x65\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));return ($ret);}Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x3a\x20\x46\x44\x23"
.$ret)."\x2e"));Common::NXCore::nxDescriptorInheritable ($ret,
(0x06e5+ 7025-0x2256));Common::NXCore::closeSocketAtFinish ($ret);return ($ret);
}sub consoleRuning{if (($consoleInitFD==(-(0x0ac3+ 5311-0x1f81)))){return (
(0x0f25+ 568-0x115d));}return ((0x1f75+ 1631-0x25d3));}"\x3f\x3f\x3f";
